SystemOrganization addCategory: #GaruthaTinyBlog!

TestCase subclass: #TBBlogTest
	instanceVariableNames: 'blog post first'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBBlogTest commentStamp: 'GabrielGermain 10/3/2018 22:22' prior: 0!
Tiny Blog tests!

!TBBlogTest methodsFor: 'setup - tear down' stamp: 'GabrielGermain 10/3/2018 22:37'!
setUp
	blog := TBBlog current.
	blog removeAllPosts.
	
	first := TBPost title: 'A title' text: 'A text' category: 'First Category'.
	blog writeBlogPost: first.
	
	post := (TBPost title: 'Another title' text: 'Another text' category: 'Second Category') beVisible.! !

!TBBlogTest methodsFor: 'setup - tear down' stamp: 'GabrielGermain 10/3/2018 22:39'!
tearDown
	TBBlog reset.! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 22:45'!
testAddBlogPost
	blog writeBlogPost: post.
	self assert: blog size equals: 2! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:11'!
testAllBlogPosts
	blog writeBlogPost: post.
	self assert: blog allBlogPosts size equals: 2! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:15'!
testAllBlogPostsFromCategory
	self assert: (blog allBlogPostsFromCategory: 'First Category')
	size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:19'!
testAllCategories
	blog writeBlogPost: post.
	self assert: blog allCategories size equals: 2! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:13'!
testAllVisibleBlogPosts
	blog writeBlogPost: post.
	self assert: blog allVisibleBlogPosts size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:17'!
testAllVisibleBlogPostsFromCategory
	blog writeBlogPost: post.
	self assert: (blog allVisibleBlogPostsFromCategory: 'First Category') size equals: 0.
	self assert: (blog allVisibleBlogPostsFromCategory: 'Second Category') size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:10'!
testRemoveAllBlogPosts
	blog removeAllPosts.
	self assert: blog size equals: 0! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:10'!
testSize
	self assert: blog size equals: 1! !

!TBBlogTest methodsFor: 'basic tests' stamp: 'GabrielGermain 10/3/2018 23:19'!
testUnclassifiedBlogPosts
	self assert: (blog allBlogPosts select: [ :p | p isUnclassified ]) size equals: 0! !

Object subclass: #TBBlog
	instanceVariableNames: 'posts'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

TBBlog class
	instanceVariableNames: 'uniqueInstance'!

!TBBlog commentStamp: 'GabrielGermain 10/3/2018 22:02' prior: 0!
I'm a Tiny Blog.!

TBBlog class
	instanceVariableNames: 'uniqueInstance'!

!TBBlog class methodsFor: 'initialize - release' stamp: 'GabrielGermain 10/16/2018 23:50'!
createDemoPosts
	"TBBlog createDemoPosts"

	self current
		writeBlogPost:
			((TBPost
				title: 'Welcome in TinyBlog'
				text: 'TinyBlog is a small blog engine made with Pharo.'
				category: 'TinyBlog') visible: true);
		writeBlogPost:
			((TBPost
				title: 'Report Pharo Sprint'
				text:
					'Friday, June 12 there was a Pharo sprint / Moose dojo. It was a
nice event with more than 15 motivated sprinters. With the help
of candies, cakes and chocolate, huge work has been done'
				category: 'Pharo') visible: true);
		writeBlogPost:
			((TBPost
				title:
					'Brick on top of Bloc -
Preview'
				text:
					'We are happy to announce the first preview
version of Brick, a new widget set created from scratch on top
of Bloc. Brick is being developed primarily by Alex Syrel
(together with Alain Plantec, Andrei Chis and myself), and the
work is sponsored by ESUG.
Brick is part of the Glamorous Toolkit effort and will provide
the basis for the new versions of the development tools.'
				category: 'Pharo') visible: true);
		writeBlogPost:
			((TBPost
				title:
					'The sad story of unclassified
blog posts'
				text: 'So sad that I can read this.') visible: true);
		writeBlogPost:
			((TBPost
				title:
					'Working with Pharo on the
Raspberry Pi'
				text:
					'Hardware is getting cheaper and many new
small devices like the famous Raspberry Pi provide new
computation power that was one once only available on regular
desktop computers.'
				category: 'Pharo') visible: true)! !

!TBBlog class methodsFor: 'initialize - release' stamp: 'GabrielGermain 10/3/2018 22:10'!
current
	^ uniqueInstance ifNil: [ uniqueInstance := self new  ]! !

!TBBlog class methodsFor: 'initialize - release' stamp: 'GabrielGermain 10/3/2018 22:10'!
initialize
	self reset! !

TBBlog initialize!

!TBBlog class methodsFor: 'initialize - release' stamp: 'GabrielGermain 10/3/2018 22:08'!
reset
	uniqueInstance := nil! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:12'!
allBlogPosts
	^ posts! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:16'!
allBlogPostsFromCategory: aCategory
	^ posts select: [ :p | p category = aCategory ]! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:21'!
allCategories
	^ (posts collect: [ :p | p category ]) asSet! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:14'!
allVisibleBlogPosts
	^ posts select: [ :p | p isVisible ]! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:18'!
allVisibleBlogPostsFromCategory: aCategory
	^ posts select: [ :p | p category = aCategory and: [ p isVisible ] ]! !

!TBBlog methodsFor: 'initialize' stamp: 'GabrielGermain 10/3/2018 22:04'!
initialize
	super initialize.
	posts := OrderedCollection new.! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:07'!
removeAllPosts
	posts removeAll.! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:09'!
size
	^ posts size.! !

!TBBlog methodsFor: 'actions' stamp: 'GabrielGermain 10/3/2018 23:08'!
writeBlogPost: aPost
	posts add: aPost.! !

Object subclass: #TBPost
	instanceVariableNames: 'title text date category visible'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBPost commentStamp: 'GabrielGermain 9/21/2018 00:23' prior: 0!
I'm a Tiny Blog Post!

!TBPost class methodsFor: 'initialize' stamp: 'GabrielGermain 9/21/2018 00:33'!
title: aTitle text: aText
	^ self new
		title: aTitle;
		text: aText;
		yourself! !

!TBPost class methodsFor: 'initialize' stamp: 'GabrielGermain 9/21/2018 00:35'!
title: aTitle text: aText category: aCategory
	^ (self title: aTitle text: aText)
		category: aCategory;
		yourself! !

!TBPost class methodsFor: 'definition' stamp: 'GabrielGermain 9/21/2018 00:30'!
unclassifiedTag
	^ 'Unclassified'! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:31'!
beVisible
	self visible: true! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
category
	^ category! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
category: anObject
	category := anObject! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
date
	^ date! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
date: anObject
	date := anObject! !

!TBPost methodsFor: 'initialize' stamp: 'GabrielGermain 9/21/2018 00:31'!
initialize
	self category: TBPost unclassifiedTag.
	self date: Date today.
	self notVisible! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:38'!
isUnclassified
	^ self category = TBPost unclassifiedTag! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:31'!
isVisible
	^ self visible! !

!TBPost methodsFor: 'action' stamp: 'GabrielGermain 9/21/2018 00:31'!
notVisible
	self visible: false! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
text
	^ text! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:24'!
text: anObject
	text := anObject! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
title
	^ title! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
title: anObject
	title := anObject! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
visible
	^ visible! !

!TBPost methodsFor: 'accessing' stamp: 'GabrielGermain 9/21/2018 00:25'!
visible: anObject
	visible := anObject! !

Object subclass: #TBTeapotWebApp
	instanceVariableNames: 'teapot'
	classVariableNames: 'Server'
	poolDictionaries: ''
	category: 'GaruthaTinyBlog'!

!TBTeapotWebApp commentStamp: 'GabrielGermain 10/10/2018 22:24' prior: 0!
I'm the teapot webapp for the tiny blog.!

!TBTeapotWebApp class methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/10/2018 22:39'!
start
	Server ifNil: [ Server := self new start ]! !

!TBTeapotWebApp class methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/10/2018 22:40'!
stop
	Server ifNotNil: [ Server stop. Server := nil ]! !

!TBTeapotWebApp methodsFor: 'accessing' stamp: 'GabrielGermain 10/16/2018 23:45'!
allPosts
	^ TBBlog current allVisibleBlogPosts! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:51'!
errorPage
	^ String
		streamContents: [ :s | 
			self renderPageHeaderOn: s.
			s << '<p>Oups, an error occurred</p>'.
			self renderPageFooterOn: s ]! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/17/2018 00:02'!
homePage
	^ String
		streamContents: [ :s | 
			self renderPageHeaderOn: s.
			s << '<h1>TinyBlog Web App</h1>'.
			s << '<ul>'.
			self allPosts
				withIndexDo: [ :aPost :index | 
					s
						<< '<li>';
						<< ('<a href="/post/' , index asString , '">');
						<< aPost title;
						<< '</a></li>' ].
			s << '</ul>'.
			self renderPageFooterOn: s ]! !

!TBTeapotWebApp methodsFor: 'initialization' stamp: 'GabrielGermain 10/10/2018 22:30'!
initialize
	super initialize.
	teapot := Teapot configure: {
		#port -> 8081.
		#debugMode -> true
	}.! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:58'!
pageForPostNumber: aPostNumber
	| currentPost |
	currentPost := self allPosts at: aPostNumber ifAbsent: [ ^ self errorPage ].
	^ String
		streamContents: [ :s | 
			self renderPageHeaderOn: s.
			s << ('<h1>' , currentPost title , '</h1>').
			s << ('<h3>' , currentPost date mmddyyyy , '</h3>').
			s << ('<p> Category: ' , currentPost category , '</p>').
			s << ('<p>' , currentPost text , '</p>').
			self renderPageFooterOn: s ]! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:47'!
renderPageFooterOn: aStream
	aStream << '</body></html>'! !

!TBTeapotWebApp methodsFor: 'rendering' stamp: 'GabrielGermain 10/16/2018 23:47'!
renderPageHeaderOn: aStream
	aStream << '<html><body>'! !

!TBTeapotWebApp methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/16/2018 23:53'!
start
	teapot
		GET: '/' -> [ self homePage ];
		GET: '/post/<id>' -> [ :request | self pageForPostNumber: (request at: #id) asNumber ];
		start! !

!TBTeapotWebApp methodsFor: 'starting/stopping' stamp: 'GabrielGermain 10/10/2018 22:34'!
stop
	teapot stop.! !

TBBlog initialize!
